Rename KDB.init to KDBinit - it was not an ISO9660 conforming name.
Modified: trunk/reactos/Makefile
Deleted: trunk/reactos/media/drivers/etc/KDB.init
Added: trunk/reactos/media/drivers/etc/KDBinit
Modified: trunk/reactos/ntoskrnl/dbg/kdb_cli.c

Modified: trunk/reactos/Makefile
--- trunk/reactos/Makefile	2005-03-06 02:06:11 UTC (rev 13845)
+++ trunk/reactos/Makefile	2005-03-06 02:34:18 UTC (rev 13846)
@@ -216,8 +216,8 @@
 	$(CP) media/nls/l_intl.nls $(BOOTCD_DIR)/reactos/l_intl.nls
 	$(HALFVERBOSEECHO) [COPY]    media/drivers/etc/services to $(BOOTCD_DIR)/reactos/services
 	$(CP) media/drivers/etc/services $(BOOTCD_DIR)/reactos/services
-	$(HALFVERBOSEECHO) [COPY]    media/drivers/etc/KDB.init to $(BOOTCD_DIR)/reactos/KDB.init
-	$(CP) media/drivers/etc/KDB.init $(BOOTCD_DIR)/reactos/KDB.init
+	$(HALFVERBOSEECHO) [COPY]    media/drivers/etc/KDBinit to $(BOOTCD_DIR)/reactos/KDBinit
+	$(CP) media/drivers/etc/KDBinit $(BOOTCD_DIR)/reactos/KDBinit
 
 bootcd_basic: bootcd_directory_layout bootcd_bootstrap_files bootcd_install_before
 
@@ -1045,8 +1045,8 @@
 	$(CP) media/nls/l_intl.nls $(INSTALL_DIR)/system32/casemap.nls
 	$(HALFVERBOSEECHO) [INSTALL] media/drivers/etc/services to $(INSTALL_DIR)/system32/drivers/etc/services
 	$(CP) media/drivers/etc/services $(INSTALL_DIR)/system32/drivers/etc/services
-	$(HALFVERBOSEECHO) [INSTALL] media/drivers/etc/KDB.init to $(INSTALL_DIR)/system32/drivers/etc/KDB.init
-	$(CP) media/drivers/etc/KDB.init $(INSTALL_DIR)/system32/drivers/etc/KDB.init
+	$(HALFVERBOSEECHO) [INSTALL] media/drivers/etc/KDBinit to $(INSTALL_DIR)/system32/drivers/etc/KDBinit
+	$(CP) media/drivers/etc/KDBinit $(INSTALL_DIR)/system32/drivers/etc/KDBinit
 
 .PHONY: install_clean install_dirs install_before
 

Deleted: trunk/reactos/media/drivers/etc/KDB.init
--- trunk/reactos/media/drivers/etc/KDB.init	2005-03-06 02:06:11 UTC (rev 13845)
+++ trunk/reactos/media/drivers/etc/KDB.init	2005-03-06 02:34:18 UTC (rev 13846)
@@ -1,15 +0,0 @@
-# Example KDB.init file
-#
-# The disassembly flavor is set to "intel" (default is "at&t") and the
-#
-
-# Set the disassembly flavor to "intel" (default is "at&t")
-set syntax intel
-
-# Change the condition to enter KDB on INT3 to "always" (default is "kmode")
-set condition INT3 first always
-
-# This is a special command available only in the KDB.init file - it breaks into
-# KDB when it is interpreting the init file at startup.
-#break
-

Copied: trunk/reactos/media/drivers/etc/KDBinit (from rev 13845, trunk/reactos/media/drivers/etc/KDB.init)

Modified: trunk/reactos/ntoskrnl/dbg/kdb_cli.c
--- trunk/reactos/ntoskrnl/dbg/kdb_cli.c	2005-03-06 02:06:11 UTC (rev 13845)
+++ trunk/reactos/ntoskrnl/dbg/kdb_cli.c	2005-03-06 02:34:18 UTC (rev 13846)
@@ -97,7 +97,7 @@
 STATIC LONG KdbNumberOfRowsTerminal = -1;
 STATIC LONG KdbNumberOfColsTerminal = -1;
 
-PCHAR KdbInitFileBuffer = NULL; /* Buffer where KDB.init file is loaded into during initialization */
+PCHAR KdbInitFileBuffer = NULL; /* Buffer where KDBinit file is loaded into during initialization */
 
 STATIC CONST struct
 {
@@ -2206,7 +2206,7 @@
    CHAR c;
 
    /* Execute the commands in the init file */
-   DbgPrint("KDB: Executing KDB.init file...\n");
+   DbgPrint("KDB: Executing KDBinit file...\n");
    p1 = KdbInitFileBuffer;
    while (p1[0] != '\0')
    {
@@ -2237,12 +2237,12 @@
       while (p1[0] == '\r' || p1[0] == '\n')
          p1++;
    }
-   DbgPrint("KDB: KDB.init executed\n");
+   DbgPrint("KDB: KDBinit executed\n");
 }
 
 /*!\brief Called when KDB is initialized
  *
  * Reads the KDB.init file from the SystemRoot\system32\drivers\etc directory and executes it.
  */
 VOID
 KdbpCliInit()
@@ -2258,7 +2258,7 @@
    ULONG OldEflags;
 
    /* Initialize the object attributes */
-   RtlInitUnicodeString(&FileName, L"\\SystemRoot\\system32\\drivers\\etc\\KDB.init");
+   RtlInitUnicodeString(&FileName, L"\\SystemRoot\\system32\\drivers\\etc\\KDBinit");
    InitializeObjectAttributes(&ObjectAttributes, &FileName, 0, NULL, NULL);
    
    /* Open the file */
@@ -2267,7 +2267,7 @@
                        FILE_NO_INTERMEDIATE_BUFFERING);
    if (!NT_SUCCESS(Status))
    {
-      DPRINT("Could not open \\SystemRoot\\system32\\drivers\\etc\\KDB.init (Status 0x%x)", Status);
+      DPRINT("Could not open \\SystemRoot\\system32\\drivers\\etc\\KDBinit (Status 0x%x)", Status);
       return;
    }
 
@@ -2277,7 +2277,7 @@
    if (!NT_SUCCESS(Status))
    {
       ZwClose(hFile);
-      DPRINT("Could not query size of \\SystemRoot\\system32\\drivers\\etc\\KDB.init (Status 0x%x)", Status);
+      DPRINT("Could not query size of \\SystemRoot\\system32\\drivers\\etc\\KDBinit (Status 0x%x)", Status);
       return;
    }
    FileSize = FileStdInfo.EndOfFile.u.LowPart;
@@ -2287,7 +2287,7 @@
    if (FileBuffer == NULL)
    {
       ZwClose(hFile);
-      DPRINT("Could not allocate %d bytes for KDB.init file\n", FileSize);
+      DPRINT("Could not allocate %d bytes for KDBinit file\n", FileSize);
       return;
    }
 
@@ -2297,7 +2297,7 @@
    if (!NT_SUCCESS(Status) && Status != STATUS_END_OF_FILE)
    {
       ExFreePool(FileBuffer);
-      DPRINT("Could not read KDB.init file into memory (Status 0x%lx)\n", Status);
+      DPRINT("Could not read KDBinit file into memory (Status 0x%lx)\n", Status);
       return;
    }
    FileSize = min(FileSize, Iosb.Information);
@@ -2237,12 +2237,12 @@
 /*!\brief Called when KDB is initialized
  *
- * Reads the KDB.init file from the SystemRoot\system32\drivers\etc directory and executes it.
+ * Reads the KDBinit file from the SystemRoot\system32\drivers\etc directory and executes it.
  */
 VOID